@@ -6,12 +6,28 @@ from django.utils.translation import ugettext_lazy as _
 
 from aparnik.utils.utils import is_app_installed
 from aparnik.contrib.users.admin import get_update_at
-from aparnik.contrib.basemodels.admin import BaseModelAdmin
+from aparnik.contrib.basemodels.admin import BaseModelAdmin, BaseModelTabularInline
 from aparnik.packages.shops.products.admin import ProductAdmin
 from aparnik.packages.shops.files.admin import FileAdmin
 from .models import Course, CourseFile, CourseSummary, BaseCourse
 
 
+class TeacherCourseInline(BaseModelTabularInline):
+    model = Course.teacher_obj.through
+    fields = ['teacher_obj', 'priority', ]
+    raw_id_fields = ('teacher_obj',)
+    extra = 1
+    exclude = []
+
+    def __init__(self, *args, **kwargs):
+        Klass = TeacherCourseInline
+        Klass_parent = BaseModelTabularInline
+
+        super(Klass, self).__init__(*args, **kwargs)
+        self.exclude = Klass_parent.exclude + self.exclude
+
+
+
 class CourseFileSortInline(admin.TabularInline):
     model = CourseFile
     fk_name = 'course_obj'
@@ -115,16 +131,49 @@ class BaseCourseAdmin(ProductAdmin):
 
 
 class CourseAdmin(BaseCourseAdmin):
-    fields = ['banner', 'cover', 'teacher_obj', 'category_obj', 'parent_obj', 'dependency_obj', 'publish_date', 'publish_month', 'publish_week', 'publish_day']
-    list_display = ['parent_obj', 'category_obj', 'price_fabric', 'dependency_obj', 'publish_month', 'publish_week', 'publish_day',
-                    get_update_at]
+    fields = [
+        'banner',
+        'cover',
+        'category_obj',
+        'parent_obj',
+        'dependency_obj',
+        'publish_date',
+        'publish_month',
+        'publish_week',
+        'publish_day'
+    ]
+    list_display = [
+        'parent_obj',
+        'category_obj',
+        'price_fabric',
+        'dependency_obj',
+        'publish_month',
+        'publish_week',
+        'publish_day',
+        get_update_at,
+    ]
 
-    search_fields = ['parent_obj__title', 'category_obj__title']
-    list_filter = [ParentFilter, DependencyFilter,]# 'publish_month', 'publish_week', 'publish_day']
+    search_fields = [
+        'parent_obj__title',
+        'category_obj__title',
+    ]
+    list_filter = [
+        ParentFilter,
+        DependencyFilter,
+    ]# 'publish_month', 'publish_week', 'publish_day']
     raw_id_fields = []
     exclude = []
-    dynamic_raw_id_fields = ['category_obj', 'parent_obj', 'dependency_obj', 'cover', 'banner']
-    inlines = [CourseFileSortInline, ]
+    dynamic_raw_id_fields = [
+        'category_obj',
+        'dependency_obj',
+        'parent_obj',
+        'cover',
+        'banner',
+    ]
+    inlines = [
+        CourseFileSortInline,
+        TeacherCourseInline,
+    ]
 
     def __init__(self, *args, **kwargs):
         Klass = CourseAdmin
