@@ -10,6 +10,7 @@ from django.utils.timezone import now
 import uuid
 from decimal import Decimal
 
+from aparnik.packages.shops.products.models import Product
 from aparnik.utils.utils import field_with_prefix
 from aparnik.utils.fields import *
 from aparnik.settings import aparnik_settings
@@ -35,23 +36,25 @@ class CouponManager(models.Manager):
 
         # check min and max order
         if order.status != order.STATUS_WAITING:
-
             raise ValidationError({'coupon': [_('This order finished before.')]})
         if coupon.min_price_order > 0 and coupon.min_price_order > order.get_total_cost_order():
-
             raise ValidationError({'coupon': [
                 Coupon.get_status_description(status_title=Coupon.COUPON_STATUS_ORDER_MINIMUM_IS_REQUIRED)]})
 
         if coupon.max_price_order > 0 and coupon.max_price_order < order.get_total_cost_order():
-
             raise ValidationError(
                 {'coupon': [Coupon.get_status_description(Coupon.COUPON_STATUS_ORDER_MAXIMUM_IS_REQUIRED)]})
 
         # check expire date
         if coupon.expire_at is not None and coupon.expire_at < now():
-
             raise ValidationError({'coupon': [Coupon.get_status_description(Coupon.COUPON_STATUS_EXPIRED)]})
 
+        # check coupon include special products
+        if coupon.products.exists():
+            product_ids = order.items.all().values_list('product_obj_id', flat=True)
+            if coupon.products.constrained_target.filter(product_obj_id__in=product_ids).count() != product_ids.count():
+                raise ValidationError({'coupon_code': [_('The coupon code entered is not valid for this course.')]})
+
         # add coupon
         if coupon.for_users == Coupon.COUPON_FOR_ALL_USER and coupon.membership_set.filter(user=user,
                                                                                            is_redeem=True).count() == 0:
@@ -121,13 +124,20 @@ class Coupon(models.Model):
     )
 
     users = models.ManyToManyField(User, through='Membership', verbose_name=_('Membership'))
-    code = models.CharField(max_length=10, blank=True, null=True, unique=True, verbose_name=_('Code'), help_text=_('If blank default no limitation.'))
-    expire_at = models.DateTimeField(blank=True, null=True, verbose_name=_('Expire at'), help_text=_('If blank default no limitation.'))
+    code = models.CharField(max_length=10, blank=True, null=True, unique=True, verbose_name=_('Code'),
+                            help_text=_('If blank default no limitation.'))
+    expire_at = models.DateTimeField(blank=True, null=True, verbose_name=_('Expire at'),
+                                     help_text=_('If blank default no limitation.'))
     value = PriceField(validators=[MinValueValidator(1)], verbose_name=_('Value'))
-    type = models.CharField(max_length=2, choices=COUPON_TYPE_CHOICES, default=COUPON_TYPE_PERCENT, verbose_name=_('type'))
-    max_price_order = PriceField(big=True, default=0, verbose_name=_('Max price of order'), help_text=_('If blank default no limitation.')) # hadaksar mablaghe factor
-    min_price_order = PriceField(big=True, default=0, verbose_name=_('Min price of order'), help_text=_('If blank default no limitation.')) # hadaghal mablaghe factor
-    for_users = models.CharField(max_length=2, choices=COUPON_FOR_CHOICES, default=COUPON_FOR_ALL_USER, verbose_name=_('For users'))
+    type = models.CharField(max_length=2, choices=COUPON_TYPE_CHOICES, default=COUPON_TYPE_PERCENT,
+                            verbose_name=_('type'))
+    products = models.ManyToManyField(Product, through='ProductCoupon', blank=True, verbose_name=_('Products'))
+    max_price_order = PriceField(big=True, default=0, verbose_name=_('Max price of order'),
+                                 help_text=_('If blank default no limitation.'))  # hadaksar mablaghe factor
+    min_price_order = PriceField(big=True, default=0, verbose_name=_('Min price of order'),
+                                 help_text=_('If blank default no limitation.'))  # hadaghal mablaghe factor
+    for_users = models.CharField(max_length=2, choices=COUPON_FOR_CHOICES, default=COUPON_FOR_ALL_USER,
+                                 verbose_name=_('For users'))
     for_limited_users_value = models.IntegerField(blank=True, null=True, verbose_name=_('Limited users value'))
 
     created_at = models.DateTimeField(auto_now_add=True, auto_now=False, verbose_name=_('Created at'))
@@ -218,7 +228,6 @@ class CouponAllUsersManager(CouponManager):
 
 
 class CouponForAllUser(Coupon):
-
     objects = CouponAllUsersManager()
 
     class Meta:
@@ -239,7 +248,6 @@ class CouponLimitedUsersManager(CouponManager):
 
 
 class CouponForLimitedUser(Coupon):
-
     objects = CouponLimitedUsersManager()
 
     class Meta:
@@ -265,7 +273,6 @@ class CouponCustomUsersManager(CouponManager):
 
 
 class CouponForCoustomUser(Coupon):
-
     objects = CouponCustomUsersManager()
 
     class Meta:
@@ -288,3 +295,20 @@ class Membership(models.Model):
     class Meta:
         verbose_name = _('Membership')
         verbose_name_plural = _('Memberships')
+
+
+class ProductCoupon(models.Model):
+    product_obj = models.ForeignKey(
+        Product,
+        on_delete=models.CASCADE,
+        verbose_name=_('Product'),
+    )
+    coupon_obj = models.ForeignKey(
+        Coupon,
+        on_delete=models.CASCADE,
+        verbose_name=_('Coupon'),
+    )
+
+    class Meta:
+        verbose_name = _('Product Coupon')
+        verbose_name_plural = _('Product Coupon relations')
