@@ -103,6 +103,7 @@ class Order(BaseModel):
     uuid = models.UUIDField(default=uuid.uuid4, unique=True, editable=False, verbose_name=_('Reference ID'))
     postal_cost_value = PriceField(big=True, default=0, verbose_name=_('Postal Cost'))
     is_sync_with_websites = models.BooleanField(default=False, verbose_name=_('Is sync with websites'))
+    whom = models.CharField(max_length=255, blank=True, null=True, db_index=True, verbose_name=_('Whom'), )
 
     objects = OrderManager()
 
@@ -457,6 +458,10 @@ class Order(BaseModel):
 
 
 def post_save_order_receiver(sender, instance, created, *args, **kwargs):
+
+    from .tasks import send_order_message
+    send_order_message.delay(instance.pk, created)
+
     from aparnik.packages.shops.vouchers.models import Voucher
     Voucher.objects.change_order(instance)
 
